@@ -30,13 +30,13 @@ class MicroConventions(StreamConventions, HorizonConventions, ValueConventions,
                     raise Exception('Cannot initialize without internet access if parameters are not supplied. Maybe check that your internet connection is working.')
                 else:
                     raise Exception('Could not initialize. Possibly due to slow internet. Maybe try again in a couple of moments.')
-        self.num_predictions = num_predictions or config["num_predictions"]
 
         # Pass arguments through to mixins
+        num_predictions = num_predictions or config["num_predictions"]
         delays = delays or config['delays']
         min_len = min_len or config["min_len"]
         min_balance = min_len or config["min_balance"]
-        super().__init__(delays=delays, min_difficulty=min_len, min_balance=min_balance)
+        super().__init__(num_predictions=num_predictions, delays=delays, min_difficulty=min_len, min_balance=min_balance)
 
     def request_get_json(self, method, arg=None, data=None, throw=True):
         """ Canonical way to call methods using requests library """
