@@ -1,17 +1,13 @@
 import re, uuid
-from microconventions.misc_conventions import MiscConventions
+from microconventions.sep_conventions import SepConventions
 
 
-class StreamConventions(object):
+class StreamConventions(SepConventions):
     # Conventions for names of streams
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-    @staticmethod
-    def sep():
-        return '::'
-
     @staticmethod
     def is_plain_name(name: str):
         return StreamConventions.is_valid_name(name) and not "~" in name
